function [ total_false_positives ] = error_false_positives( targets, data_association, step, total_false_positives )
%ERROR_FALSE_POSITIVES % This function finds False Positives errors 
% (i.e.  when a hypothesis doesn't match with any real object) according to
%  the object-hypothesis mapping between real input and estimated output  
%   INPUT
%       targets                 Structure with the properties of each target at each step for instants 1 to k (ID, position (cluster head), radius, target_type(candidate, confirmed or deleted))
%       data_association        Object-Hypothesis mapping
%       step                    Current instant
%       total_false_positives   Number of false positives errors in previous steps
%   OUTPUT
%       total_false positives   Number of false positives errors in current step

    current_targets = 0;
    ntargets = length(targets(:,step));
    for t = 1:ntargets
        if isstruct(targets{t,step})
            current_targets = current_targets + 1;
        end
    end
    current_false_positives = current_targets - sum(data_association(:,2,step)>0);
    total_false_positives = total_false_positives + current_false_positives;

end

