function [ particle_targets, particle_filters, ids ] = particle_filtering( particle_targets, particle_filters, particle_boundaries, ids, n_memory, step )
%PARTICLE_FILTERING This function computes an estimation on actual position of
%the target using a Particle filter.
    % INPUT:
        % particle_targets
        % n_memory
        % step 
    % OUTPUT:
        % particle_targets

    % Initializing variables
    f = 0;
    n_particles = 1000;
    % Searching memory...
    empty_steps = [];   % Searchs if a previous target exists
    for s = 1:step-1
        for p = 1:length(particle_targets(:,step))
        empty_steps(p,s) = isstruct(particle_targets{p,s});
        end
    end
    
    if step>1
        if length(empty_steps(:,1))>1
            empty_steps = sum(empty_steps);
        end
    end
    
    if step <= n_memory  % In case that first target appears in an instant less than N steps
        n = step-1;
    else
        n = n_memory;
    end

    ntargets = length(particle_targets(:,step));

    for t = 1:ntargets
        if isstruct(particle_targets{t,step})
            if isempty(ids)
                ids = particle_targets{t,step}.ID;
                particle_filters{1,particle_targets{t,step}.ID}.ID = particle_targets{t,step}.ID;
                particle_filters{1,particle_targets{t,step}.ID}.pf = robotics.ParticleFilter;
                particle_filters{1,particle_targets{t,step}.ID}.pf.StateEstimationMethod = 'mean'; % Mean state estimator
                particle_filters{1,particle_targets{t,step}.ID}.pf.ResamplingMethod = 'systematic'; % Systematic resampling method
                % Initializing filter
                initialize( particle_filters{1,particle_targets{t,step}.ID}.pf, n_particles, particle_boundaries);
                
            elseif isempty(find(ids == particle_targets{t,step}.ID,1))
                ids = [ids particle_targets{t,step}.ID]; 
                particle_filters{1,particle_targets{t,step}.ID}.ID = particle_targets{t,step}.ID;
                particle_filters{1,particle_targets{t,step}.ID}.pf = robotics.ParticleFilter;
                particle_filters{1,particle_targets{t,step}.ID}.pf.StateEstimationMethod = 'mean'; % Mean state estimator
                particle_filters{1,particle_targets{t,step}.ID}.pf.ResamplingMethod = 'systematic'; % Systematic resampling method
                % Initializing filter
                initialize(particle_filters{1,particle_targets{t,step}.ID}.pf, n_particles, particle_boundaries);
            end
            
            if sum(empty_steps((step-n):(step-1)))>0
                % Target EXISTS in last N steps (frames)
                pos = find((empty_steps(1:(step-1)))>0); % Previous steps with existing targets
                pos = pos((pos<step)&(pos>(step-n)));
                for i = length(pos):-1:1
                    ntargets_pre = length(particle_targets(:,pos(i)));
                    if ntargets_pre>0
                        for t_pre = 1:ntargets_pre
                            if isstruct(particle_targets{t_pre,pos(i)})
                                if particle_targets{t,step}.ID == particle_targets{t_pre,pos(i)}.ID
                                    if particle_targets{t,step}.position == particle_targets{t_pre,pos(i)}.position 
                                        particle_targets{t,step}.particle_X_est = particle_targets{t_pre,pos(i)}.particle_X_est;   
                                        f = 1;
                                        break;
                                    else  
                                        % Particle filtering

                                        % TIME UPDATE --> PREDICTION
                                        [targetPredicted, targetCov] = predict(particle_filters{1,particle_targets{t,step}.ID}.pf);

                                        % MEASUREMENT UPDATE --> CORRECTION
                                        [particle_targets{t,step}.particle_X_est, targetCov] = correct(particle_filters{1,particle_targets{t,step}.ID}.pf,particle_targets{t,step}.position);
                                        break;
                                    end
                                end
                            end
                        end
                        if f
                            break;
                        end
                    end
                end
            end
        end
    end
end

