function [ total_deviation, total_deviation_kalman, total_deviation_particle, n_matches, MOTP, MOTP_kalman,...
    MOTP_particle, max_deviation, max_deviation_kalman, max_deviation_particle ]...
    = tracking_deviation( data_association, step, total_deviation, total_deviation_kalman, total_deviation_particle, n_matches, precision )
%TRACKING_DEVIATION This function keeps track of the number of deviations
% and object-hypothesis matches in time in order to calculate the
% performance metric MOTP.
%   INPUT 
%       data_association            Array ((2 IDs + dmin) x (n_object2hypothesis_associations) x n_steps)
%       step                        Current instant
%       total_deviation             Accumulative deviation in previous steps
%       total_deviation_kalman      Accumulative deviation in previous steps with Kalman filtering
%       n_matches                   Number of object-hypothesis matches in previous instants
%       precision                   Meters per voxel
%   OUTPUT
%       total_deviation             Accumulative deviation in previous steps + current deviation
%       total_deviation_kalman      Accumulative deviation in previous steps + current deviation with Kalman Filtering
%       n_matches                   Number of object-hypothesis matches
%       MOTP                        Multi Object Tracking Precision (Performance Metric)
%       MOTP_kalman                 Multi Object Tracking Precision (Performance Metric) with Kalman Filtering
%       max_deviation               Overall Maximum Deviation in meters [m]
%       max_deviation_kalman        Overall Maximum Deviation in meters [m] with Kalman Filtering


    n_matches = n_matches + length(find(sum(data_association(:,:,step),2)>0));

    total_deviation = total_deviation + sum(data_association(:,3,step))*precision;
    total_deviation_kalman = total_deviation_kalman + sum(data_association(:,4,step))*precision;
    total_deviation_particle = total_deviation_particle + sum(data_association(:,5,step))*precision;

    max_deviation = max(max(data_association(:,3,:)))*precision;
    max_deviation_kalman = max(max(data_association(:,4,:)))*precision;
    max_deviation_particle = max(max(data_association(:,5,:)))*precision;

    MOTP = total_deviation/n_matches;
    MOTP_kalman = total_deviation_kalman/n_matches;
    MOTP_particle = total_deviation_particle/n_matches;

end

